@@ -224,6 +224,12 @@ PLAN_RESULT_SCHEMA = '''{
                             "minimum": 0,
                             "type": "integer"
                         },
+                        "plan_orders_count": {
+                            "format": "int32",
+                            "maximum": 9000,
+                            "minimum": 0,
+                            "type": "integer"
+                        },
                         "quality": {
                             "additionalProperties": false,
                             "nullable": true,
@@ -349,6 +355,12 @@ PLAN_RESULT_SCHEMA = '''{
                             "format": "double",
                             "minimum": 0,
                             "type": "number"
+                        },
+                        "waitlist_orders_count": {
+                            "format": "int32",
+                            "maximum": 9000,
+                            "minimum": 0,
+                            "type": "integer"
                         }
                     },
                     "required": [
@@ -356,6 +368,8 @@ PLAN_RESULT_SCHEMA = '''{
                         "reward",
                         "measurements",
                         "orders_count",
+                        "plan_orders_count",
+                        "waitlist_orders_count",
                         "performers_count"
                     ],
                     "type": "object"
@@ -597,6 +611,12 @@ PLAN_RESULT_SCHEMA = '''{
                                         "minimum": 0,
                                         "type": "integer"
                                     },
+                                    "plan_orders_count": {
+                                        "format": "int32",
+                                        "maximum": 9000,
+                                        "minimum": 0,
+                                        "type": "integer"
+                                    },
                                     "quality": {
                                         "additionalProperties": false,
                                         "nullable": true,
@@ -722,6 +742,12 @@ PLAN_RESULT_SCHEMA = '''{
                                         "format": "double",
                                         "minimum": 0,
                                         "type": "number"
+                                    },
+                                    "waitlist_orders_count": {
+                                        "format": "int32",
+                                        "maximum": 9000,
+                                        "minimum": 0,
+                                        "type": "integer"
                                     }
                                 },
                                 "required": [
@@ -729,6 +755,8 @@ PLAN_RESULT_SCHEMA = '''{
                                     "reward",
                                     "measurements",
                                     "orders_count",
+                                    "plan_orders_count",
+                                    "waitlist_orders_count",
                                     "performers_count"
                                 ],
                                 "type": "object"
